@@ -96,6 +96,9 @@ class Ag3:
         self._cache_cnv_hmm = dict()
         self._cache_cnv_coverage_calls = dict()
         self._cache_cnv_discordant_read_calls = dict()
+        self._cache_haplotypes = dict()
+        self._cache_haplotype_sites = dict()
+        self._cache_cohort_metadata = dict()
 
     @property
     def releases(self):
@@ -347,7 +350,7 @@ class Ag3:
         field="filter_pass",
         analysis="dt_20200416",
         inline_array=True,
-        chunks="auto",
+        chunks="native",
     ):
         """Access SNP site filters.
 
@@ -400,7 +403,7 @@ class Ag3:
         site_mask=None,
         site_filters="dt_20200416",
         inline_array=True,
-        chunks="auto",
+        chunks="native",
     ):
         """Access SNP site data (positions and alleles).
 
@@ -480,7 +483,7 @@ class Ag3:
         site_mask=None,
         site_filters="dt_20200416",
         inline_array=True,
-        chunks="auto",
+        chunks="native",
     ):
         """Access SNP genotypes and associated data.
 
@@ -548,7 +551,7 @@ class Ag3:
             self._cache_genome = zarr.open_consolidated(store=store)
         return self._cache_genome
 
-    def genome_sequence(self, contig, inline_array=True, chunks="auto"):
+    def genome_sequence(self, contig, inline_array=True, chunks="native"):
         """Access the reference genome sequence.
 
         Parameters
@@ -638,6 +641,60 @@ class Ag3:
 
         return is_accessible
 
+    def _site_mask_ids(self, site_filters):
+        if site_filters == "dt_20200416":
+            return "gamb_colu_arab", "gamb_colu", "arab"
+        else:
+            raise ValueError
+
+    def _snp_df(self, transcript, site_filters="dt_20200416"):
+        """Set up a dataframe with SNP site and filter columns."""
+
+        # get feature direct from geneset
+        gs = self.geneset()
+        feature = gs[gs["ID"] == transcript].squeeze()
+        contig = feature.contig
+
+        # grab pos, ref and alt for chrom arm from snp_sites
+        pos, ref, alt = self.snp_sites(contig=contig)
+
+        # sites are dask arrays, turn pos into sorted index
+        pos = allel.SortedIndex(pos.compute())
+
+        # locate transcript range
+        loc_feature = pos.locate_range(feature.start, feature.end)
+
+        # dask compute on the sliced arrays to speed things up
+        pos = pos[loc_feature]
+        ref = ref[loc_feature].compute()
+        alt = alt[loc_feature].compute()
+
+        # access site filters
+        filter_pass = dict()
+        masks = self._site_mask_ids(site_filters=site_filters)
+        for m in masks:
+            x = self.site_filters(contig=feature.contig, mask=m, analysis=site_filters)
+            x = x[loc_feature].compute()
+            filter_pass[m] = x
+
+        # setup columns with contig, pos, ref, alt columns
+        cols = {
+            "contig": contig,
+            "position": np.repeat(pos, 3),
+            "ref_allele": np.repeat(ref.astype("U1"), 3),
+            "alt_allele": alt.astype("U1").flatten(),
+        }
+
+        # add mask columns
+        for m in masks:
+            x = filter_pass[m]
+            cols[f"pass_{m}"] = np.repeat(x, 3)
+
+        # construct dataframe
+        df_snps = pandas.DataFrame(cols)
+
+        return contig, loc_feature, df_snps
+
     def snp_effects(self, transcript, site_mask=None, site_filters="dt_20200416"):
         """Compute variant effects for a gene transcript.
 
@@ -656,62 +713,66 @@ class Ag3:
 
         """
 
-        # get feature direct from geneset
-        gs = self.geneset()
-        feature = gs[gs["ID"] == transcript].squeeze()
-
-        # grab pos, ref and alt for chrom arm from snp_sites
-        pos, ref, alt = self.snp_sites(contig=feature.contig)
-
-        # sites are dask arrays, turn pos into sorted index
-        pos = allel.SortedIndex(pos.compute())
-
-        # locate transcript range
-        loc_feature = pos.locate_range(feature.start, feature.end)
-
-        # dask compute on the sliced arrays to speed things up
-        pos = pos[loc_feature]
-        ref = ref[loc_feature].compute()
-        alt = alt[loc_feature].compute()
-
-        # apply site mask if requested
-        if site_mask is not None:
-            # access filters for whole contig
-            loc_sites = self.site_filters(
-                contig=feature.contig, mask=site_mask, analysis=site_filters
-            )
-            # slice to feature and compute
-            loc_sites = loc_sites[loc_feature].compute()
-            # apply site filter
-            pos = pos[loc_sites]
-            ref = ref[loc_sites]
-            alt = alt[loc_sites]
-
-        # build an initial dataframe with contig, pos, ref, alt columns
-        cols = {
-            "position": np.repeat(pos, 3),
-            "ref_allele": np.repeat(ref.astype("U1"), 3),
-            "alt_allele": alt.astype("U1").flatten(),
-        }
-        df_variants = pandas.DataFrame(cols)
-
-        # take an AGAP transcript ID and get meta data from the gff using veff
-        # first time sets up and caches ann object
+        # setup initial dataframe of SNPs
+        _, _, df_snps = self._snp_df(transcript=transcript, site_filters=site_filters)
 
+        # setup variant effect annotator
         if self._cache_annotator is None:
             self._cache_annotator = veff.Annotator(
                 genome=self.open_genome(), geneset=self.geneset()
             )
         ann = self._cache_annotator
 
-        df_effects = ann.get_effects(transcript=transcript, variants=df_variants)
+        # apply mask if requested
+        if site_mask is not None:
+            loc_sites = df_snps[f"pass_{site_mask}"]
+            df_snps = df_snps.loc[loc_sites]
+
+        # reset index after filtering
+        df_snps.reset_index(inplace=True, drop=True)
+
+        # add effects to the dataframe
+        df_effects = ann.get_effects(transcript=transcript, variants=df_snps)
 
         return df_effects
 
+    def _prep_cohorts_arg(self, cohorts, sample_sets, species_calls, cohorts_analysis):
+
+        # build cohort dictionary where key=cohort_id, value=loc_coh
+        coh_dict = {}
+        if isinstance(cohorts, dict):
+            # get sample metadata
+            df_meta = self.sample_metadata(
+                sample_sets=sample_sets, species_calls=species_calls
+            )
+            for coh, query in cohorts.items():
+                # locate samples
+                loc_coh = df_meta.eval(query).values
+                coh_dict[coh] = loc_coh
+        if isinstance(cohorts, str):
+            # grab the cohorts dataframe
+            df_coh = self.sample_cohorts(
+                sample_sets=sample_sets, cohorts_analysis=cohorts_analysis
+            )
+            # fix the string to match columns
+            cohorts = "cohort_" + cohorts
+            # check the given cohort set exists
+            if cohorts not in df_coh.columns:
+                raise ValueError(f"{cohorts!r} is not a known cohort set")
+            # remove the nan rows
+            for coh in df_coh[cohorts].unique():
+                if isinstance(coh, str):
+                    loc_coh = df_coh[cohorts] == coh
+                    coh_dict[coh] = loc_coh.values
+
+        return coh_dict
+
     def snp_allele_frequencies(
         self,
         transcript,
         cohorts,
+        cohorts_analysis="20210702",
+        min_cohort_size=10,
         site_mask=None,
         site_filters="dt_20200416",
         species_calls=("20200422", "aim"),
@@ -724,9 +785,17 @@ class Ag3:
         ----------
         transcript : str
             Gene transcript ID (AgamP4.12), e.g., "AGAP004707-RA".
-        cohorts : dict
-            Dictionary to map cohort IDs to sample queries, e.g.,
-            {"bf_2012_col": "country == 'Burkina Faso' and year == 2012 and species == 'coluzzii'"}
+        cohorts : str or dict
+            If a string, gives the name of a predefined cohort set, e.g., one of
+            {"admin1_month", "admin1_year", "admin2_month", "admin2_year"}.
+            If a dict, should map cohort labels to sample queries, e.g.,
+            `{"bf_2012_col": "country == 'Burkina Faso' and year == 2012 and species == 'coluzzii'"}`.
+        cohorts_analysis : str
+            Cohort analysis identifier (date of analysis), default is latest version.
+        min_cohort_size : int
+            Minimum cohort size, below which allele frequencies are not calculated for cohorts.
+            Please note, NaNs will be returned for any cohorts with fewer samples than min_cohort_size,
+            these can be removed from the output dataframe using pandas df.dropna(axis='columns').
         site_mask : {"gamb_colu_arab", "gamb_colu", "arab"}
             Site filters mask to apply.
         site_filters : str, optional
@@ -743,24 +812,18 @@ class Ag3:
 
         Returns
         -------
-        df : pandas.DataFrame
+        df_snps : pandas.DataFrame
+
+        Notes
+        -----
+        NaNs will be returned for any cohorts with fewer samples than min_cohort_size,
+        these can be removed from the output dataframe using pandas df.dropna(axis='columns').
 
         """
-        # get feature details (don't need to set up an annotator here)
-        geneset = self.geneset().set_index("ID")
-        feature = geneset.loc[transcript]
-        contig = feature.contig
 
-        # grab pos, ref and alt for chrom arm from snp_sites
-        pos, ref, alt = self.snp_sites(contig=contig)
-
-        # locate transcript range
-        pos = allel.SortedIndex(pos.compute())
-        loc_feature = pos.locate_range(feature.start, feature.end)
-
-        # we want to grab all metadata then get idx for samples we want
-        df_meta = self.sample_metadata(
-            sample_sets=sample_sets, species_calls=species_calls
+        # setup initial dataframe of SNPs
+        contig, loc_feature, df_snps = self._snp_df(
+            transcript=transcript, site_filters=site_filters
         )
 
         # get genotypes
@@ -770,58 +833,50 @@ class Ag3:
             field="GT",
         )
 
-        # slice everything to feature location
-        pos = pos[loc_feature]
-        ref = ref[loc_feature].compute()
-        alt = alt[loc_feature].compute()
+        # slice to feature location
         gt = gt[loc_feature].compute()
 
+        # build coh dict
+        coh_dict = self._prep_cohorts_arg(
+            cohorts=cohorts,
+            sample_sets=sample_sets,
+            species_calls=species_calls,
+            cohorts_analysis=cohorts_analysis,
+        )
+
+        # count alleles
+        for coh, loc_coh in coh_dict.items():
+            n_samples = np.count_nonzero(loc_coh)
+            if n_samples == 0:
+                raise ValueError(f"no samples for cohort {coh!r}")
+            if n_samples < min_cohort_size:
+                df_snps[coh] = np.nan
+            else:
+                gt_coh = np.compress(loc_coh, gt, axis=1)
+                # count alleles
+                ac_coh = allel.GenotypeArray(gt_coh).count_alleles(max_allele=3)
+                # compute allele frequencies
+                af_coh = ac_coh.to_frequencies()
+                # add column to dataframe
+                df_snps[coh] = af_coh[:, 1:].flatten()
+
+        # add max allele freq column
+        df_snps["max_af"] = df_snps[list(coh_dict.keys())].max(axis=1)
+
         # apply site mask if requested
         if site_mask is not None:
-            # access filters for whole contig
-            loc_sites = self.site_filters(
-                contig=feature.contig, mask=site_mask, analysis=site_filters
-            )
-            # slice to feature and compute
-            loc_sites = loc_sites[loc_feature].compute()
-            # apply site filter
-            pos = pos[loc_sites]
-            ref = ref[loc_sites]
-            alt = alt[loc_sites]
-            gt = gt[loc_sites]
-
-        # count alleles
-        afs = dict()
-        for coh, query in cohorts.items():
-            loc_coh = df_meta.eval(query).values
-            gt_coh = da.compress(loc_coh, gt, axis=1)
-            ac_coh = (
-                allel.GenotypeDaskArray(gt_coh).count_alleles(max_allele=3).compute()
-            )
-            afs[coh] = ac_coh.to_frequencies()
-
-        # set up columns
-        cols = {
-            "position": np.repeat(pos, 3),
-            "ref_allele": np.repeat(ref.astype("U1"), 3),
-            "alt_allele": alt.astype("U1").flatten(),
-        }
-
-        for coh in cohorts:
-            cols[coh] = afs[coh][:, 1:].flatten()
-
-        # build df
-        df = pandas.DataFrame(cols)
-
-        # add max allele freq column
-        df["max_af"] = df[cohorts].max(axis=1)
+            loc_sites = df_snps[f"pass_{site_mask}"]
+            df_snps = df_snps.loc[loc_sites]
 
         # drop invariants
         if drop_invariant:
-            loc_variant = df["max_af"] > 0
-            df = df[loc_variant]
+            loc_variant = df_snps["max_af"] > 0
+            df_snps = df_snps.loc[loc_variant]
 
-        return df
+        # reset index after filtering
+        df_snps.reset_index(inplace=True, drop=True)
+
+        return df_snps
 
     def cross_metadata(self):
         """Load a dataframe containing metadata about samples in colony crosses, including
@@ -890,7 +945,7 @@ class Ag3:
         site_mask=None,
         site_filters="dt_20200416",
         inline_array=True,
-        chunks="auto",
+        chunks="native",
     ):
         """Load site annotations.
 
@@ -1004,7 +1059,7 @@ class Ag3:
         site_mask=None,
         site_filters="dt_20200416",
         inline_array=True,
-        chunks="auto",
+        chunks="native",
     ):
         """Access SNP sites, site filters and genotype calls.
 
@@ -1173,7 +1228,7 @@ class Ag3:
         contig,
         sample_sets="v3_wild",
         inline_array=True,
-        chunks="auto",
+        chunks="native",
     ):
         """Access CNV HMM data.
 
@@ -1268,7 +1323,7 @@ class Ag3:
         sample_set,
         analysis,
         inline_array=True,
-        chunks="auto",
+        chunks="native",
     ):
         """Access CNV HMM data.
 
@@ -1469,7 +1524,7 @@ class Ag3:
         contig,
         sample_sets="v3_wild",
         inline_array=True,
-        chunks="auto",
+        chunks="native",
     ):
         """Access CNV discordant read calls data.
 
@@ -1602,7 +1657,15 @@ class Ag3:
 
         return ds_out
 
-    def gene_cnv_frequencies(self, contig, cohorts=None, sample_sets="v3_wild"):
+    def gene_cnv_frequencies(
+        self,
+        contig,
+        cohorts,
+        cohorts_analysis="20210702",
+        min_cohort_size=10,
+        species_calls=("20200422", "aim"),
+        sample_sets="v3_wild",
+    ):
         """Compute modal copy number by gene, then compute the frequency of
         amplifications and deletions in one or more cohorts, from HMM data.
 
@@ -1610,9 +1673,19 @@ class Ag3:
         ----------
         contig : str
             Chromosome arm, e.g., "3R".
-        cohorts : dict
-            Dictionary to map cohort IDs to sample queries, e.g.,
-            {"bf_2012_col": "country == 'Burkina Faso' and year == 2012 and species == 'coluzzii'"}
+        cohorts : str or dict
+            If a string, gives the name of a predefined cohort set, e.g., one of
+            {"admin1_month", "admin1_year", "admin2_month", "admin2_year"}.
+            If a dict, should map cohort labels to sample queries, e.g.,
+            `{"bf_2012_col": "country == 'Burkina Faso' and year == 2012 and species == 'coluzzii'"}`.
+        cohorts_analysis : str
+            Cohort analysis identifier (date of analysis), default is latest version.
+        min_cohort_size : int
+            Minimum cohort size, below which allele frequencies are not calculated for cohorts.
+            Please note, NaNs will be returned for any cohorts with fewer samples than min_cohort_size,
+            these can be removed from the output dataframe using pandas df.dropna(axis='columns').
+        species_calls : (str, str)
+            Include species calls in metadata.
         sample_sets : str or list of str
             Can be a sample set identifier (e.g., "AG1000G-AO") or a list of sample set
             identifiers (e.g., ["AG1000G-BF-A", "AG1000G-BF-B"]) or a release identifier (e.g.,
@@ -1622,20 +1695,25 @@ class Ag3:
         -------
         df : pandas.DataFrame
 
+        Notes
+        -----
+        NaNs will be returned for any cohorts with fewer samples than min_cohort_size,
+        these can be removed from the output dataframe using pandas df.dropna(axis='columns').
+
         """
 
         # get gene copy number data
         ds_cnv = self.gene_cnv(contig=contig, sample_sets=sample_sets)
 
         # get sample metadata
-        df_samples = self.sample_metadata(sample_sets=sample_sets)
+        df_meta = self.sample_metadata(sample_sets=sample_sets)
 
         # get genes
         df_genes = self.geneset().query(f"type == 'gene' and contig == '{contig}'")
 
         # figure out expected copy number
         if contig == "X":
-            is_male = (df_samples["sex_call"] == "M").values
+            is_male = (df_meta["sex_call"] == "M").values
             expected_cn = np.where(is_male, 1, 2)[np.newaxis, :]
         else:
             expected_cn = 2
@@ -1648,28 +1726,278 @@ class Ag3:
         # setup intermediates
         cn = ds_cnv["CN_mode"].values
         is_amp = cn > expected_cn
-        is_del = (0 <= cn) & (cn < expected_cn)
+        is_del = (cn >= 0) & (cn < expected_cn)
+
+        # set up cohort dict
+        # build coh dict
+        coh_dict = self._prep_cohorts_arg(
+            cohorts=cohorts,
+            sample_sets=sample_sets,
+            species_calls=species_calls,
+            cohorts_analysis=cohorts_analysis,
+        )
 
         # compute cohort frequencies
-        for coh, query in cohorts.items():
-            loc_samples = df_samples.eval(query).values
+        for coh, loc_samples in coh_dict.items():
             n_samples = np.count_nonzero(loc_samples)
             if n_samples == 0:
                 raise ValueError(f"no samples for cohort {coh!r}")
-            is_amp_coh = np.compress(loc_samples, is_amp, axis=1)
-            is_del_coh = np.compress(loc_samples, is_del, axis=1)
-            amp_count_coh = np.sum(is_amp_coh, axis=1)
-            del_count_coh = np.sum(is_del_coh, axis=1)
-            amp_freq_coh = amp_count_coh / n_samples
-            del_freq_coh = del_count_coh / n_samples
-            df[f"{coh}_amp"] = amp_freq_coh
-            df[f"{coh}_del"] = del_freq_coh
+            if n_samples < min_cohort_size:
+                df[f"{coh}_amp"] = np.nan
+                df[f"{coh}_del"] = np.nan
+            else:
+                is_amp_coh = np.compress(loc_samples, is_amp, axis=1)
+                is_del_coh = np.compress(loc_samples, is_del, axis=1)
+                amp_count_coh = np.sum(is_amp_coh, axis=1)
+                del_count_coh = np.sum(is_del_coh, axis=1)
+                amp_freq_coh = amp_count_coh / n_samples
+                del_freq_coh = del_count_coh / n_samples
+                df[f"{coh}_amp"] = amp_freq_coh
+                df[f"{coh}_del"] = del_freq_coh
 
         # set gene ID as index for convenience
         df.set_index("ID", inplace=True)
 
         return df
 
+    def open_haplotypes(self, sample_set, analysis):
+        """Open haplotypes zarr.
+
+        Parameters
+        ----------
+        sample_set : str
+        analysis : {"arab", "gamb_colu", "gamb_colu_arab"}
+
+        Returns
+        -------
+        root : zarr.hierarchy.Group
+
+        """
+        try:
+            return self._cache_haplotypes[(sample_set, analysis)]
+        except KeyError:
+            release = self._lookup_release(sample_set=sample_set)
+            path = f"{self._path}/{release}/snp_haplotypes/{sample_set}/{analysis}/zarr"
+            store = SafeStore(FSMap(root=path, fs=self._fs, check=False, create=False))
+            # some sample sets have no data for a given analysis, handle this
+            if ".zmetadata" not in store:
+                root = None
+            else:
+                root = zarr.open_consolidated(store=store)
+            self._cache_haplotypes[(sample_set, analysis)] = root
+        return root
+
+    def open_haplotype_sites(self, analysis):
+        """Open haplotype sites zarr.
+
+        Parameters
+        ----------
+        analysis : {"arab", "gamb_colu", "gamb_colu_arab"}
+
+        Returns
+        -------
+        root : zarr.hierarchy.Group
+
+        """
+        try:
+            return self._cache_haplotype_sites[analysis]
+        except KeyError:
+            path = f"{self._path}/v3/snp_haplotypes/sites/{analysis}/zarr"
+            store = SafeStore(FSMap(root=path, fs=self._fs, check=False, create=False))
+            root = zarr.open_consolidated(store=store)
+            self._cache_haplotype_sites[analysis] = root
+        return root
+
+    def _haplotypes_dataset(self, contig, sample_set, analysis, inline_array, chunks):
+
+        # open zarr
+        root = self.open_haplotypes(sample_set=sample_set, analysis=analysis)
+        sites = self.open_haplotype_sites(analysis=analysis)
+
+        # some sample sets have no data for a given analysis, handle this
+        if root is None:
+            return None
+
+        coords = dict()
+        data_vars = dict()
+
+        # variant_position
+        pos = sites[f"{contig}/variants/POS"]
+        coords["variant_position"] = (
+            [DIM_VARIANT],
+            from_zarr(pos, inline_array=inline_array, chunks=chunks),
+        )
+
+        # variant_contig
+        contig_index = self.contigs.index(contig)
+        coords["variant_contig"] = (
+            [DIM_VARIANT],
+            da.full_like(pos, fill_value=contig_index, dtype="u1"),
+        )
+
+        # variant_allele
+        ref = from_zarr(
+            sites[f"{contig}/variants/REF"], inline_array=inline_array, chunks=chunks
+        )
+        alt = from_zarr(
+            sites[f"{contig}/variants/ALT"], inline_array=inline_array, chunks=chunks
+        )
+        variant_allele = da.hstack([ref[:, None], alt[:, None]])
+        data_vars["variant_allele"] = [DIM_VARIANT, DIM_ALLELE], variant_allele
+
+        # call_genotype
+        data_vars["call_genotype"] = (
+            [DIM_VARIANT, DIM_SAMPLE, DIM_PLOIDY],
+            from_zarr(
+                root[f"{contig}/calldata/GT"], inline_array=inline_array, chunks=chunks
+            ),
+        )
+
+        # sample arrays
+        coords["sample_id"] = (
+            [DIM_SAMPLE],
+            from_zarr(root["samples"], inline_array=inline_array, chunks=chunks),
+        )
+
+        # setup attributes
+        attrs = {"contigs": self.contigs}
+
+        # create a dataset
+        ds = xarray.Dataset(data_vars=data_vars, coords=coords, attrs=attrs)
+
+        return ds
+
+    def haplotypes(
+        self,
+        contig,
+        analysis,
+        sample_sets="v3_wild",
+        inline_array=True,
+        chunks="native",
+    ):
+        """Access haplotype data.
+
+        Parameters
+        ----------
+        contig : str
+            Chromosome arm, e.g., "3R".
+        analysis : {"arab", "gamb_colu", "gamb_colu_arab"}
+            Which phasing analysis to use. If analysing only An. arabiensis, the "arab" analysis
+            is best. If analysing only An. gambiae and An. coluzzii, the "gamb_colu" analysis is
+            best. Otherwise use the "gamb_colu_arab" analysis.
+        sample_sets : str or list of str
+            Can be a sample set identifier (e.g., "AG1000G-AO") or a list of sample set
+            identifiers (e.g., ["AG1000G-BF-A", "AG1000G-BF-B"]) or a release identifier (e.g.,
+            "v3") or a list of release identifiers.
+        inline_array : bool, optional
+            Passed through to dask.array.from_array().
+        chunks : str, optional
+            If 'auto' let dask decide chunk size. If 'native' use native zarr chunks.
+            Also can be a target size, e.g., '200 MiB'.
+
+        Returns
+        -------
+        ds : xarray.Dataset
+
+        """
+
+        sample_sets = self._prep_sample_sets_arg(sample_sets=sample_sets)
+
+        if isinstance(sample_sets, str):
+
+            # single sample set requested
+            ds = self._haplotypes_dataset(
+                contig=contig,
+                sample_set=sample_sets,
+                analysis=analysis,
+                inline_array=inline_array,
+                chunks=chunks,
+            )
+
+        else:
+
+            # multiple sample sets requested, need to concatenate along samples dimension
+            datasets = [
+                self._haplotypes_dataset(
+                    contig=contig,
+                    sample_set=sample_set,
+                    analysis=analysis,
+                    inline_array=inline_array,
+                    chunks=chunks,
+                )
+                for sample_set in sample_sets
+            ]
+            # some sample sets have no data for a given analysis, handle this
+            datasets = [d for d in datasets if d is not None]
+            if len(datasets) == 0:
+                ds = None
+            else:
+                ds = xarray.concat(
+                    datasets,
+                    dim=DIM_SAMPLE,
+                    data_vars="minimal",
+                    coords="minimal",
+                    compat="override",
+                    join="override",
+                )
+
+        # if no samples at all, raise
+        if ds is None:
+            raise ValueError(
+                f"no samples available for analysis {analysis!r} and sample sets {sample_sets!r}"
+            )
+
+        return ds
+
+    def _read_cohort_metadata(self, *, sample_set, cohorts_analysis):
+        """Read cohort metadata for a single sample set."""
+        try:
+            return self._cache_cohort_metadata[(sample_set, cohorts_analysis)]
+        except KeyError:
+            release = self._lookup_release(sample_set=sample_set)
+            path = f"{self._path}/{release}/metadata/cohorts_{cohorts_analysis}/{sample_set}/samples.cohorts.csv"
+            with self._fs.open(path) as f:
+                df = pandas.read_csv(f, na_values="")
+
+            self._cache_cohort_metadata[(sample_set, cohorts_analysis)] = df
+            return df
+
+    def sample_cohorts(self, sample_sets="v3_wild", cohorts_analysis="20210702"):
+        """Access cohorts metadata for one or more sample sets.
+
+        Parameters
+        ----------
+        sample_sets : str or list of str
+            Can be a sample set identifier (e.g., "AG1000G-AO") or a list of sample set
+            identifiers (e.g., ["AG1000G-BF-A", "AG1000G-BF-B"]) or a release identifier (e.g.,
+            "v3") or a list of release identifiers.
+        cohorts_analysis : str
+            Cohort analysis identifier (date of analysis), default is latest version.
+        Returns
+        -------
+        df : pandas.DataFrame
+
+        """
+        sample_sets = self._prep_sample_sets_arg(sample_sets=sample_sets)
+
+        if isinstance(sample_sets, str):
+            # assume single sample set
+            df = self._read_cohort_metadata(
+                sample_set=sample_sets, cohorts_analysis=cohorts_analysis
+            )
+
+        else:
+            # concatenate multiple sample sets
+            dfs = [
+                self._read_cohort_metadata(
+                    sample_set=c, cohorts_analysis=cohorts_analysis
+                )
+                for c in sample_sets
+            ]
+            df = pandas.concat(dfs, axis=0, sort=False).reset_index(drop=True)
+
+        return df
+
 
 @numba.njit("Tuple((int8, int64))(int8[:], int8)")
 def _cn_mode_1d(a, vmax):
